﻿var sfo = {};
sfo.sys = {};

/*
* Enum (Sfo.Sys.Web.Controls.Entities.Enum.EUiType)
*/
sfo.sys.uiType = {
    label: "label",
    text: "text",
    autocomplete: "autocomplete",
    select: "select",
    datePicker: "datePicker",
    button: "button",
    submit: "submit",
    checkbox: "checkBox",
    checkboxGroup: "checkboxGroup",
    radio: "radio",
    radioGroup: "radioGroup",
    file: "file",
    hidden: "hidden",
    link: "link",
    address: "address",
    custom: "custom"
};


sfo.sys.Control = function(jqControl, enabled, params) {
    this.control = jqControl;
    this.enabled = enabled;
    this.params = params;
};

sfo.sys.ControlBuilder = {
    
};

sfo.sys.ControlBuilder.buildControl = function (item) {
    if (item.uiType == sfo.sys.uiType.select) {
        this.createSelect(item);
    }
    if (item.uiType == sfo.sys.uiType.select) {
        this.createTextBox(item);
    }
};

sfo.sys.ControlBuilder.createLabel = function (title) {
    return $('<label>', { text: title });
};

sfo.sys.ControlBuilder.createSubLabel = function (title) {
    return $('<sub>', { text: title }).css('color','#3333ba').css("display", "block");
};

sfo.sys.ControlBuilder.createTextBox = function (value) {
    var textbox = $("<input>", { type: "text", value: value });
    textbox.setMaxLength = function(length) {
        this.attr('maxlength', length);
        return this;
    };
    return textbox;
};

sfo.sys.ControlBuilder.createSelect = function (source, value) {
    var result = $("<select>");

    for (var ii in source) {
        var sourceItem = source[ii];
        var option = $("<option>", { value: sourceItem.value, text: sourceItem.displayName }).appendTo(result);
        if (sourceItem.selected || value == sourceItem.value)
            option.attr('selected', 'selected');
    }

    result.getSelectedValue = function () {
        return this.find('option:selected').val();
    };
    return result;

};

sfo.sys.ControlBuilder.createCheckBox = function (value) {
    var input = $("<input>", { type: "checkbox", value: value });
    if (value)
        input.attr("checked", "checked");
    return input;
};

sfo.sys.ControlBuilder.createGroupBox = function (title) {
    var result = $("<fieldset>");
    $("<legend>", { text: title }).appendTo(result);
    return result;
};

sfo.sys.ControlBuilder.createFileUpload = function (title, url, src, data, accept) {
    var filebox = $('<div>', { title: title }).addClass('file-outer');
    var name = "file" + $.guid;
    var input = $("<input>", { type: "file", name: name });
    if (accept) {
        input.attr("accept", accept);
    }

    input.appendTo($('<div>', { title: title })
        .addClass('file-innner')
        .css('background-image', 'url(content/image/' + src + ".png)")
        .appendTo(filebox));
    return filebox;
};

sfo.sys.ControlBuilder.createFileUpload2 = function(img, title, callback) {
    var result = sfo.sys.ControlBuilder.createFileUpload(title, "", img, null, "*" /*"application/pkcs10"*/);
    result.find(".file-innner").css("width", "32px").css("height", "32px").css("background-size", "32px 32px");
    result.find(".file-outer").css("display", "inline-block");
    result.find('input').eq(0)
    .data('sender', result)
    .data('sender-data', { img: img, title: title })
    .data('callback', callback)
    .bind("change", function () {
        var innerCallback = $(this).data('callback'),
            sender = $(this).data('sender');
        if (innerCallback)
            innerCallback($(this));

        if (sender) {
            var senderData = $(this).data('sender-data');
            var parent = sender[0].parentElement;
            $(parent).html('');
            sender = sfo.sys.ControlBuilder.createFileUpload2(senderData.img, senderData.title, innerCallback);
            $(sender).appendTo(parent);
        }
    });

    return result;
};

sfo.sys.ControlBuilder.setFileUploadDelegate = function(control, img, title,  callback) {
    control.find('input').eq(0)
    .data('sender', control)
    .data('sender-data', { img: img, title: title })
    .data('callback', callback)
    .bind("change", function () {
        var innerCallback = $(this).data('callback'),
            sender = $(this).data('sender');
        if (innerCallback)
            innerCallback($(this));

        if (sender) {
            var senderData = $(this).data('sender-data');
            var parent = sender[0].parentElement;
            $(parent).html('');
            sender = sfo.sys.ControlBuilder.createFileUpload2(senderData.img, senderData.title, innerCallback);
            $(sender).appendTo(parent);
        }
    });

    return control;
};


sfo.sys.ControlBuilder.createLink = function (title, href) {
    return $("<a>", { text: title, href: href });
};

sfo.sys.ControlBuilder.createButton = function (title) {
    return $("<button>", { text: title });
};

sfo.sys.ControlBuilder.createImageButton = function (title, src) {
    return $("<button>", { title: title }).addClass("image-button").css('background-image', 'url(content/image/' + src + ".png)");
};

sfo.sys.ControlBuilder.createImage = function (src, title, alt) {
    var result = $("<img>", { src: "/content/image/" + src + ".png" });
    if (title)
        result.attr("title", title);
    if (alt)
        result.attr("alt", alt);
    result.setSize = function(width, heidth) {
        $(result).css('width', width).css('height', heidth);
    };
    return result;
};


sfo.sys.ControlBuilder.createUpdown = function(value) {
    var textbox = this.createTextBox(value)
        .setMaxLength(3)
        .addClass("updown")
        .bind('keydown', function(event) {
            var chr = String.fromCharCode(event.which);
        return !("0123456789".indexOf(chr) < 0 && event.which != 8 && event.which != 46 && event.which != 36 && event.which != 35 && event.which != 37 && event.which != 39);
    });
    return textbox;
};

sfo.sys.ControlBuilder.createBlock = function (text) {
    if (!text)
        return $("<div>");
    return $("<div>", { text: text });
};

sfo.sys.ControlBuilder.createView = function (view) {
    return $(view);
};

sfo.sys.ControlBuilder.createAddressInput = function (value, item, modelName) {
    var
        values = [],
        table = $("<table>").css("width", "100%"),
        titles = [
            {
                title: "Почтовый индекс",
                length: 6,
                name: "post"
            },
            {
                title: "Область",
                name: "area"
            },
            {
                title: "Район",
                sub: "(Если не город)",
                length: 30,
                name: "region"
            },
            {
                title: "Город",
                length: 30,
                name: "city"
            },
            {
                title: "Населенный пункт",
                sub: "(Если не город)",
                length: 30,
                name: "town"
            },
            {
                title: "Улица",
                length: 40,
                name: "street"
            },
            {
                title: "Дом",
                length: 5,
                name: "house"
            },
            {
                title: "Корпус",
                length: 2,
                name: "block"
            },
            {
                title: "Квартира/офис",
                length: 5,
                name: "flat"
            }
        ];
        
        if (value) {
            var temp = value.replace("Россия,","").split(",");
            if (temp.length < 8) values = ['', '', '', '', '', '', '', '', ''];
            else values = temp;
        }

    for (var ii = 0; ii < titles.length; ii++) {
        var tr = $("<tr>").appendTo(table),
            tdTitle = $("<td>").appendTo(tr),
            tdInput = $("<td>").appendTo(tr);

        this.createLabel(titles[ii].title).appendTo(tdTitle);
        if (titles[ii].sub)
            this.createSubLabel(titles[ii].sub).appendTo(tdTitle);
        if (ii == 1) {
            this.createSelect(sfo.sys.Geo.regions, values[ii])
                .attr("id", titles[ii].name)
                .data('item', item)
                .data('values', values)
                .bind('change', onChange)
                .css("width", "97%")
                .addClass("addr" + ii)
                .appendTo(tdInput);
        } else {
            this.createTextBox(values[ii])
                .setMaxLength(titles[ii].length)
                .attr("id", titles[ii].name)
                .data('item', item)
                .data('values', values)
                .bind('change', onChange)
                .css("width", "97%")
                .addClass("addr"+ii)
                .appendTo(tdInput);
        }
        
    }

    table.setEnable = function(enabled) {
        table.find('input, select').each(function() {
            $(this).prop('disabled', 'disabled');
        });
    };

    table.validate = function (summary) {
        var post = table.find("#post").eq(0).val(),
            region = table.find("#region").eq(0).val(),
            city = table.find("#city").eq(0).val(),
            town = table.find("#town").eq(0).val(),
            street = table.find("#street").eq(0).val(),
            house = table.find("#house").eq(0).val();

        if (!post) {

            //summary.add(new sfo.sys.Error("Не указн почтовый индекс"));
        }

        if (post && region && town && street && house) {
            table.find("#post").eq(0).removeClass("warrning");
            table.find("#region").eq(0).removeClass("warrning");
            table.find("#city").eq(0).removeClass("warrning");
            table.find("#town").eq(0).removeClass("warrning");
            table.find("#street").eq(0).removeClass("warrning");
            table.find("#house").eq(0).removeClass("warrning");
            return true;
        }

        if (post && city && street && house) {
            table.find("#post").eq(0).removeClass("warrning");
            table.find("#region").eq(0).removeClass("warrning");
            table.find("#city").eq(0).removeClass("warrning");
            table.find("#town").eq(0).removeClass("warrning");
            table.find("#street").eq(0).removeClass("warrning");
            table.find("#house").eq(0).removeClass("warrning");
            return true;
        }
        if (!post && !region && !city && !town && !street && !house) {
            // summary.add(new sfo.sys.Error("Не заполнен Адрес!"));} //processed common validation
            table.find("#post").eq(0).addClass("warrning");
            table.find("#region").eq(0).addClass("warrning");
            table.find("#city").eq(0).addClass("warrning");
            table.find("#town").eq(0).addClass("warrning");
            table.find("#street").eq(0).addClass("warrning");
            table.find("#house").eq(0).addClass("warrning");
        }
        else
            summary.add(new sfo.sys.Error("Неверно указан адрес! Нужно ввести почтовый индекс, область, регион, населенный пункт, улицу и дом либо почтовый индекс, область, город, улицу и дом, для ИП или ФЛ номер квартиры."));
    };

    return table;

    function onChange () {
        var dataItem = $(this).data('item'),
            dataValues = $(this).data('values');
        var index = $(this).attr('class').replace("addr", "").replace("warrning","").replace(" ", "");
        
        if ($(this)[0].tagName.toLowerCase() == "select")
            dataValues[index] = $(this).find("option:selected").val();
        else {
            var val = $(this).val();
            if (!val || val == 'undefined')
                val = "";
            dataValues[index] = val;
        }
            

        var resultValue = "";
        for (var xx = 0; xx < dataValues.length; xx++) {
            if (dataValues[xx] == 'undefined')
                resultValue += ",";
            else
                resultValue += dataValues[xx] + ",";
        }

        resultValue = resultValue.substr(0, resultValue.length - 1);
       // alert(resultValue);
        dataItem.value = "Россия," + resultValue;
        if (modelName) {
            var model = sfo.sys.Proxy.getModel(modelName);
            if (model)
                model.isValid();
        }
        
    }

};

sfo.sys.go = function(url) {
    location.href = url;
};

sfo.sys.getJson = function (url) {
    var result = null;
    $.ajax({
        url: url,
        async: false,
        cache: false,
        success: function (data) {
            result = data;
        },
        error: function (e) {
        if (e && e.status == 200)
            result = eval(e.responseText);
        }
});
if (result && (typeof (result) === 'string' || result instanceof String))
    try {
        var temp = jQuery.parseJSON(result);
        result = temp;
    } catch (e) {
        return result;
    } 
        
    return result;
};

sfo.sys.sendRequest = function (url, requestData, err) {
    var result = null;
    $.ajax({
        url: url,
        async: false,
        type: "POST",
        cache: false,
        data: requestData,
        success: function (postback) {
            result = postback;
        },
        error: function (e) {
            err = e;
        }
    });
    if (result && (typeof (result) === 'string' || result instanceof String))
        try {
            var temp = jQuery.parseJSON(result);
            result = temp;
        } catch (e) {
            return result;
        } 
      
    return result;
};


sfo.sys.sendForm = function(url, params, method) {
    method = method || "post"; // Set method to post by default if not specified.

    // The rest of this code assumes you are not using a library.
    // It can be made less wordy if you use one.
    var form = document.createElement("form");
    form.setAttribute("method", method);
    form.setAttribute("action", url);

    for (var key in params) {
        if (params.hasOwnProperty(key)) {
            var hiddenField = document.createElement("input");
            hiddenField.setAttribute("type", "hidden");
            hiddenField.setAttribute("name", key);
            hiddenField.setAttribute("value", params[key]);

            form.appendChild(hiddenField);
        }
    }

    document.body.appendChild(form);
    form.submit();
};


sfo.sys.post = function(url, data) {
    sfo.sys.sendForm(url, { data: JSON.stringify(sfo.sys.utils.clone(data)) });
};

sfo.sys.postJson = function (url, data, err, extParams) {
    var sendData = "data=" + sfo.sys.toDataString(data);
    if (extParams)
        sendData += "&" + extParams;
    return sfo.sys.sendRequest(url, sendData, err);
};

sfo.sys.sendWizardStep = function (url, step, data, err) {
    return sfo.sys.sendRequest(url, "step=" + step + "&data=" + sfo.sys.toDataString(data), err);
};

sfo.sys.toDataString = function(data) {
    return encodeURIComponent(JSON.stringify(sfo.sys.utils.clone(data)));
};

sfo.sys.postFile = function(url, fileControl, data, succ, err) {
//    if (!$.browser.msie) {
        $.ajaxFileUpload({
            url: url,
            secureuri: false,
            fileElement: fileControl,
           //` dataType: 'html',
            data: data,
            success: function(postdata, status) {
                if (succ) {
                    succ(postdata);
                }
            },
            error: function(postdata, status, e) {
                err = postdata;
            }
        });
//    } else {
//        $(fileControl).fileupload({});
//    }

};

sfo.sys.Proxy = {
    _models: [],
    addOrUpdateModel: function (name, validator, data) {
        var model = this.getModel(name);
        if (!model) {
            model = new sfo.sys.Proxy.StateModel(name, validator, data);
            this._models.push(model);
        } else {
            model._validator = validator;
            model.data = data;
        }
        return model;
    },
    getModel: function (name) {
        for (var ii = 0; ii < this._models.length; ii++) {
            if (this._models[ii]._name == name)
                return this._models[ii];
        }
        return null;
    },
    clearModel: function (name) {
        var temp = [];
        for (var ii = 0; ii < this._models.length; ii++) {
            if (this._models[ii]._name == name) {
                continue;
            }
            temp.push(this._models[ii]);
        }
        this._models = temp;
    },
    onValidateModel: function (name, delegate) {
        var model = this.getModel(name);
        if (model) {
            model._validator._validatorDelegate = delegate;
        }
    },
    _summaries: [],
    addOrUpdateSummary: function(name, block) {
        var summary = this.getSummary(name);
        if (!summary) {
            summary = new sfo.sys.Proxy.Summary(name, block);
            this._summaries.push(summary);
        } else {
            summary._block = block;
        }
        return summary;
    },
    getSummary: function(name) {
        for (var ii = 0; ii < this._summaries.length; ii++) {
            if (this._summaries[ii]._name == name)
                return this._summaries[ii];
        }
        return null;
    }
};

sfo.sys.Proxy.StateModel = function (name, validator, data) {
    this._name = name;  
    this._validator = validator;
    this.data = data;
};

sfo.sys.Proxy.StateModel.prototype = {
    isValid: function () {
        return this._validator.validate();
    }
};

sfo.sys.Proxy.Summary = function(name, block) {
    this._name = name;
    this._block = block;
};

sfo.sys.Proxy.Summary.prototype = {    
    clear : function() {
        this._block.html('');
    },
    add: function (message) {
        var list = this._block.find("ul");
        if (list.length == 0) {
            list = $('<ul>').appendTo(this._block);
        }

        if (sfo.sys.Error.is(message))
            $("<li>", { text: message.errorMessage }).addClass("error").appendTo(list);
        
        if (sfo.sys.Warring.is(message))
            $("<li>", { text: message.warringMessage }).addClass("warrning").appendTo(list);

    },
    addRange: function(messages) {
        if (messages && messages.length > 0) {
            for (var ii = 0; ii < messages.length; ii++) {
                this.add(messages[ii]);
            }
        }
    }
};

(function($) {
    $.fn.summary = function() {
        sfo.sys.Proxy.addOrUpdateSummary($(this).attr('id'), $(this));
        return $(this);
    };
})(jQuery);

sfo.sys.Error = function (message) {
    this.errorMessage = message;
};

sfo.sys.Error.is = function(errorObject) {
    if (!errorObject)
        return false;

    return errorObject.hasOwnProperty("errorMessage");
};

sfo.sys.Warring = function (message) {
    this.warringMessage = message;
};

sfo.sys.Warring.is = function (warringObject) {
    if (!warringObject)
        return false;

    return warringObject.hasOwnProperty("warringMessage");
};

sfo.sys.Message = function (message) {
    this.textMessage = message;
};

sfo.sys.Message.is = function (messageObject) {
    if (!messageObject)
        return false;

    return messageObject.hasOwnProperty("textMessage");
};

sfo.sys.Success = function () {
    return [];
};

sfo.sys.ValidationResult = function(done, errorMessage) {
    this.done = done;
    this.errorMessage = errorMessage;
};

sfo.sys.utils = {
    isJson: function(result) {
        try {
            jQuery.parseJSON(result);
            return true;
        } catch (e) {
            return false;
        } 
    },
    toJson: function(result) {
        return jQuery.parseJSON(result);
    }
};

sfo.sys.utils.RowCollection = function (gridviewData) {
    if (!gridviewData)
        throw new Error("NullReferenceExption: RowCollection.gridviewData");

    this.length = gridviewData.length; // row count
    for (var ii = 0; ii < this.length; ii++) {
        this[ii] = gridviewData[ii];
    }
};

sfo.sys.utils.RowCollection.prototype = {
    getColumns: function (column) {
        var result = [];
        if ($.isNumeric(column))
            for (var ii = 0; ii < this.length; ii++) {
                result.push(this[ii][column]);
            }
        if (typeof column === "string") {
            for (var ii = 0; ii < this.length; ii++) {
                for (var jj = 0; jj < this[ii].length; jj++)
                    if (this[ii][jj].name == column)
                        result.push(this[ii][jj]);
            }
        }

        result.equal = function(value) {
            for (var ll = 0; ll < this.length; ll++) {
                if (this[ll].name == value)
                    return true;
            }
            return false;
        };

        result.get = function (value) {
            var res = [];
            for (var ll = 0; ll < this.length; ll++) {
                if (this[ll].name == value)
                    res.push(this[ll]);
            }
            return res;
        };

        return result;
    }
};

sfo.sys.utils.Row = function (gridviewDataRow) {
    if (!gridviewDataRow)
        throw new Error("NullReferenceExption: RowCollection.gridviewData");
    this.length = gridviewDataRow.length; //column count
    for (var ii = 0; ii < this.length; ii++) {
        this[ii] = gridviewDataRow[ii];
    }
};

sfo.sys.utils.Row.prototype = {
    getColumn: function(column) {
        if (typeof column === "string") {
            for (var ii = 0; ii < this.length; ii++) {
                if (this[ii]["name"] == column)
                    return this[ii];
            }
        }
        return null;
    }
};


sfo.sys.utils.clone = function (obj) {
    // Handle the 3 simple types, and null or undefined
    if (null == obj || "object" != typeof obj) return obj;

    // Handle Date
    if (obj instanceof Date) {
        var copy = new Date();
        copy.setTime(obj.getTime());
        return copy;
    }

    // Handle Array
    if (obj instanceof Array) {
        var copy = [];
        for (var i = 0, len = obj.length; i < len; i++) {
            copy[i] = this.clone(obj[i]);
        }
        return copy;
    }

    // Handle Object
    if (obj instanceof Object) {
        var copy = {};
        for (var attr in obj) {
            if (attr == 'control' || attr == 'validate')
                continue;
            if (obj.hasOwnProperty(attr)) copy[attr] = this.clone(obj[attr]);
        }
        return copy;
    }

    throw new Error("Unable to copy obj! Its type isn't supported.");
};

sfo.sys.utils.MaskInput = function(control, mask) {
    this._control = control;
    this._mask = mask;
};

sfo.sys.utils.MaskInput.prototype = {
    _numbers: "0123456789",
    _special: "+-*/()\\{} %@#!?",
    _keys: {
        backspace: 9,
        tab: 0
    },
    match: function(chr) {

    }
};

sfo.sys.utils.Url = {};

sfo.sys.utils.Url.getParam = function(param) {
    
    var element = $("<a>").attr("href", location.hash.substr(1));
   


    function getJsonFromUrl(prm) {
        var query = element[0].search.substr(1);
        var result = "";
        query.split("&").forEach(function (part) {
            var item = part.split("=");
            if (item[0] == prm)
                result = decodeURIComponent(item[1]);
        });
        return result;
    }

    return getJsonFromUrl(param);
};

(function($) {


    var CustomView = function(settings, owner) {
        this.settings = settings;
        if (!settings.data)
            this.data = {};
        else this.data = settings.data;
        this.init(owner);
    };

    CustomView.prototype = {
        init: function(owner) {
            if (this.settings.data) {
                
            }
            if (this.settings.controls) {
                for (var ii = 0; ii < this.settings.controls.length; ii++) {
                    for (var jj in this.settings.controls[ii]) {
                        var control = this.settings.controls[ii][jj];
                        control.appendTo(owner);
                        if (control.is("input")) {
                            this.data[jj] = control.val();
                            control
                                .data('data', { data: this.data, field: jj })
                                .bind('change',function() {
                                    var item = $(this).data('data');
                                    item.data[item.field] = $(this).val();
                                });

                        }
                        if (control.is("select")) {
                            this.data[jj] = control.getSelectedValue();
                        }
                    }
                }
            }
        },
        validate: function() {
            var result = new sfo.sys.Success();
            if (this.settings.validate) {
                if (!this.data || this.data.length == 0) {
                    this.data = this.settings.data;
                }
                result = this.settings.validate(this.data);
            }
            return result;
        }
    };
   

    $.fn.customview = function(options) {
        if (!options)
            return this;

        this.settings = options;
        var cv = new CustomView(options, this);
        sfo.sys.Proxy.addOrUpdateModel(options.modelName, cv, cv.data);

        return this;
    };


})(jQuery);

var COOKIE_ID = "";
$(function() {
    COOKIE_ID = $("#ccode").val();
});


sfo.sys.utils.Date = {
    get_currentDate: function() {
        var date = new Date();
        return this._toFormat(date.getDay(), date.getMonth(), date.getFullYear());
    },

    get_prevQuarter: function() {
        var date = new Date();
        var mm = date.getMonth(), yy = date.getFullYear();
        if (mm > 3)
            return this._toFormat(1, mm - 3, yy);
        if (mm == 3)
            return this._toFormat(1, 12, yy - 1);

        return this._toFormat(1, 12 - (3 - mm), yy - 1);
    },

    _toFormat: function(d, m, y) {
        var dd = d, mm = m, yy = y;
        if (dd < 10)
            dd = "0" + d;
        if (mm < 10)
            mm = "0" + m;
        return dd + "." + mm + "." + yy;
    }
};


sfo.sys.Geo = {};
sfo.sys.Geo.regions = [
  {displayName: '01 Республика Адыгея (Адыгея)', value: '01 Республика Адыгея (Адыгея)'},
  {displayName: '02 Республика Башкортостан', value: '02 Республика Башкортостан'},
  {displayName: '03 Республика Бурятия', value: '03 Республика Бурятия'},
  {displayName: '04 Республика Алтай', value: '04 Республика Алтай'},
  {displayName: '05 Республика Дагестан', value: '05 Республика Дагестан'},
  {displayName: '06 Республика Ингушетия', value: '06 Республика Ингушетия'},
  {displayName: '07 Кабардино-Балкарская Республика', value: '07 Кабардино-Балкарская Республика'},
  {displayName: '08 Республика Калмыкия', value: '08 Республика Калмыкия'},
  {displayName: '09 Карачаево-Черкесская Республика', value: '09 Карачаево-Черкесская Республика'},
  {displayName: '10 Республика Карелия', value: '10 Республика Карелия'},
  {displayName: '11 Республика Коми', value: '11 Республика Коми'},
  {displayName: '12 Республика Марий Эл', value: '12 Республика Марий Эл'},
  {displayName: '13 Республика Мордовия', value: '13 Республика Мордовия'},
  {displayName: '14 Республика Саха (Якутия)', value: '14 Республика Саха (Якутия)'},
  {displayName: '15 Республика Северная Осетия – Алания', value: '15 Республика Северная Осетия – Алания'},
  {displayName: '16 Республика Татарстан', value: '16 Республика Татарстан'},
  {displayName: '17 Республика Тыва', value: '17 Республика Тыва'},
  {displayName: '18 Удмуртская Республика', value: '18 Удмуртская Республика'},
  {displayName: '19 Республика Хакасия', value: '19 Республика Хакасия'},
  {displayName: '20 Чеченская Республика', value: '20 Чеченская Республика'},
  {displayName: '21 Чувашская Республика – Чувашия', value: '21 Чувашская Республика – Чувашия'},
  {displayName: '22 Алтайский край', value: '22 Алтайский край'},
  {displayName: '23 Краснодарский край', value: '23 Краснодарский край'},
  {displayName: '24 Красноярский край', value: '24 Красноярский край'},
  {displayName: '25 Приморский край', value: '25 Приморский край'},
  {displayName: '26 Ставропольский край', value: '26 Ставропольский край'},
  {displayName: '27 Хабаровский край', value: '27 Хабаровский край'},
  {displayName: '28 Амурская область', value: '28 Амурская область'},
  {displayName: '29 Архангельская область и Ненецкий автономный округ', value: '29 Архангельская область и Ненецкий автономный округ'},
  {displayName: '30 Астраханская область', value: '30 Астраханская область'},
  {displayName: '31 Белгородская область', value: '31 Белгородская область'},
  {displayName: '32 Брянская область', value: '32 Брянская область'},
  {displayName: '33 Владимирская область', value: '33 Владимирская область'},
  {displayName: '34 Волгоградская область', value: '34 Волгоградская область'},
  {displayName: '35 Вологодская область', value: '35 Вологодская область'},
  {displayName: '36 Воронежская область', value: '36 Воронежская область'},
  {displayName: '37 Ивановская область', value: '37 Ивановская область'},
  {displayName: '38 Иркутская область', value: '38 Иркутская область'},
  {displayName: '39 Калининградская область', value: '39 Калининградская область'},
  {displayName: '40 Калужская область', value: '40 Калужская область'},
  {displayName: '41 Камчатский край', value: '41 Камчатский край'},
  {displayName: '42 Кемеровская область', value: '42 Кемеровская область'},
  {displayName: '43 Кировская область', value: '43 Кировская область'},
  {displayName: '44 Костромская область', value: '44 Костромская область'},
  {displayName: '45 Курганская область', value: '45 Курганская область'},
  {displayName: '46 Курская область', value: '46 Курская область'},
  {displayName: '47 Ленинградская область', value: '47 Ленинградская область'},
  {displayName: '48 Липецкая область', value: '48 Липецкая область'},
  {displayName: '49 Магаданская область', value: '49 Магаданская область'},
  {displayName: '50 Московская область', value: '50 Московская область'},
  {displayName: '51 Мурманская область', value: '51 Мурманская область'},
  {displayName: '52 Нижегородская область', value: '52 Нижегородская область'},
  {displayName: '53 Новгородская область', value: '53 Новгородская область'},
  {displayName: '54 Новосибирская область', value: '54 Новосибирская область'},
  {displayName: '55 Омская область', value: '55 Омская область'},
  {displayName: '56 Оренбургская область', value: '56 Оренбургская область'},
  {displayName: '57 Орловская область', value: '57 Орловская область'},
  {displayName: '58 Пензенская область', value: '58 Пензенская область'},
  {displayName: '59 Пермский край', value: '59 Пермский край'},
  {displayName: '60 Псковская область', value: '60 Псковская область'},
  {displayName: '61 Ростовская область', value: '61 Ростовская область'},
  {displayName: '62 Рязанская область', value: '62 Рязанская область'},
  {displayName: '63 Самарская область', value: '63 Самарская область'},
  {displayName: '64 Саратовская область', value: '64 Саратовская область'},
  {displayName: '65 Сахалинская область', value: '65 Сахалинская область'},
  {displayName: '66 Свердловская область', value: '66 Свердловская область'},
  {displayName: '67 Смоленская область', value: '67 Смоленская область'},
  {displayName: '68 Тамбовская область', value: '68 Тамбовская область'},
  {displayName: '69 Тверская область', value: '69 Тверская область'},
  {displayName: '70 Томская область', value: '70 Томская область'},
  {displayName: '71 Тульская область', value: '71 Тульская область'},
  {displayName: '72 Тюменская область', value: '72 Тюменская область'},
  {displayName: '73 Ульяновская область', value: '73 Ульяновская область'},
  {displayName: '74 Челябинская область', value: '74 Челябинская область'},
  {displayName: '75 Забайкальский край', value: '75 Забайкальский край'},
  {displayName: '76 Ярославская область', value: '76 Ярославская область'},
  {displayName: '77 г. Москва', value: '77 г. Москва'},
  {displayName: '78 г. Санкт-Петербург', value: '78 г. Санкт-Петербург'},
  {displayName: '79 Еврейская автономная область', value: '79 Еврейская автономная область'},
  {displayName: '86 Ханты-Мансийский автономный округ – Югра', value: '86 Ханты-Мансийский автономный округ – Югра'},
  {displayName: '87 Чукотский автономный округ', value: '87 Чукотский автономный округ'},
  {displayName: '89 Ямало-Ненецкий автономный округ', value: '89 Ямало-Ненецкий автономный округ'},
  {displayName: '99 Иные территории, включая, г. Байконур', value: '99 Иные территории, включая, г. Байконур'}
];

(function () {
    var matched, browser;

    // Use of jQuery.browser is frowned upon.
    // More details: http://api.jquery.com/jQuery.browser
    // jQuery.uaMatch maintained for back-compat
    jQuery.uaMatch = function (ua) {
        ua = ua.toLowerCase();

        var match = /(chrome)[ \/]([\w.]+)/.exec(ua) ||
            /(webkit)[ \/]([\w.]+)/.exec(ua) ||
            /(opera)(?:.*version|)[ \/]([\w.]+)/.exec(ua) ||
            /(msie) ([\w.]+)/.exec(ua) ||
            ua.indexOf("compatible") < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec(ua) ||
            [];

        return {
            browser: match[1] || "",
            version: match[2] || "0"
        };
    };

    matched = jQuery.uaMatch(navigator.userAgent);
    browser = {};

    if (matched.browser) {
        browser[matched.browser] = true;
        browser.version = matched.version;
    }

    // Chrome is Webkit, but Webkit is also Safari.
    if (browser.chrome) {
        browser.webkit = true;
    } else if (browser.webkit) {
        browser.safari = true;
    }

    jQuery.browser = browser;
})();

sfo.sys.utils.Validaters = {};

sfo.sys.utils.Validaters.isEmail = function (email) {
    var re = /^(([^<>()[\]\\.,;:\s@@\"]+(\.[^<>()[\]\\.,;:\s@@\"]+)*)|(\".+\"))@@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    return re.test(email);
}